@@ -37,7 +37,7 @@ pub use chrono::{
 use chrono::{prelude::*, Duration};
 use eframe::{
     egui,
-    egui::{Area, Color32, DragValue, Frame, Id, Key, Order, Response, Ui, Widget},
+    egui::{Area, Color32, DragValue, Frame, Id, Key, Order, Response, RichText, Ui, Widget},
 };
 use num_traits::FromPrimitive;
 
@@ -45,7 +45,7 @@ use num_traits::FromPrimitive;
 /// - sunday_first: `false`
 /// - movable: `false`
 /// - format_string: `"%Y-%m-%d"`
-/// - weekend_days: `[Weekday::Sat, Weekday::sun]`
+/// - weekend_func: `date.weekday() == Weekday::Sat || date.weekday() == Weekday::Sun`
 pub struct DatePicker<'a, Tz>
 where
     Tz: TimeZone,
@@ -56,8 +56,8 @@ where
     sunday_first: bool,
     movable: bool,
     format_string: String,
-    weekend_days: Vec<Weekday>,
     weekend_color: Color32,
+    weekend_func: fn(&Date<Tz>) -> bool,
     highlight_weekend: bool,
 }
 
@@ -74,8 +74,8 @@ where
             sunday_first: false,
             movable: false,
             format_string: String::from("%Y-%m-%d"),
-            weekend_days: vec![Weekday::Sat, Weekday::Sun],
             weekend_color: Color32::from_rgb(196, 0, 0),
+            weekend_func: |date| date.weekday() == Weekday::Sat || date.weekday() == Weekday::Sun,
             highlight_weekend: true,
         }
     }
@@ -119,6 +119,12 @@ where
         self
     }
 
+    /// Set function, which will decide if date is a weekend day or not.
+    pub fn weekend_days(mut self, is_weekend: fn(&Date<Tz>) -> bool) -> Self {
+        self.weekend_func = is_weekend;
+        self
+    }
+
     /// Draw names of week days as 7 columns of grid without calling `Ui::end_row`
     fn show_grid_header(&mut self, ui: &mut Ui) {
         let day_indexes = if self.sunday_first {
@@ -178,7 +184,7 @@ where
                 if self.date.month() != date.month() {
                     ui.style_mut().visuals.button_frame = false;
                 }
-                if self.highlight_weekend && self.weekend_days.contains(&date.weekday()) {
+                if self.highlight_weekend && (self.weekend_func)(&date) {
                     ui.style_mut().visuals.override_text_color = Some(self.weekend_color);
                 }
                 if ui.button(date.day().to_string()).clicked() {
@@ -201,7 +207,7 @@ where
 
     /// Draw button with text and add duration to current date when that button is clicked.
     fn date_step_button(&mut self, ui: &mut Ui, text: impl ToString, duration: Duration) {
-        if ui.button(text).clicked() {
+        if ui.button(text.to_string()).clicked() {
             *self.date = self.date.clone() + duration;
         }
     }
@@ -224,10 +230,9 @@ where
         self.date_step_button(ui, "<", Duration::days(-30));
         let month_string = chrono::Month::from_u32(self.date.month()).unwrap().name();
         // TODO: When https://github.com/emilk/egui/pull/543 is merged try to change label to combo box.
-        ui.add(
-            egui::Label::new(format!("{: <9}", month_string))
-                .text_style(egui::TextStyle::Monospace),
-        );
+        ui.add(egui::Label::new(
+            RichText::new(format!("{: <9}", month_string)).text_style(egui::TextStyle::Monospace),
+        ));
         // let mut selected = self.date.month0() as usize;
         // egui::ComboBox::from_id_source(self.id.with("month_combo_box"))
         //     .selected_text(selected)
@@ -248,7 +253,7 @@ where
 {
     fn ui(mut self, ui: &mut Ui) -> Response {
         let formated_date = self.date.format(&self.format_string);
-        let button_response = ui.button(formated_date);
+        let button_response = ui.button(formated_date.to_string());
         if button_response.clicked() {
             ui.memory().toggle_popup(self.id);
         }
